@@ -1,10 +1,15 @@
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <sys/param.h>
 
 #include <ctype.h>
 #include <getopt.h>
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 
 #include <paper.h>
 
@@ -14,18 +19,7 @@
 #define MAXPATHLEN 4096
 #endif
 
-
-#if __STDC__ - 0 == 0
-#define const
-#define void
-#endif
-
-#if __STDC__ - 0 == 0
-static usage(name)
-    char* name;
-#else
 static void usage(const char* name)
-#endif
 {
     fprintf(stderr,
 	"usage: %s [ [ -p ] papername | -d | -a ] [ -z ] [ -n | -N ] [ -s | -w | -h ] [ -c | -m | -i ]\n",
@@ -46,15 +40,8 @@ static void usage(const char* name)
 
 #define INCHxCM 2.54
 
-#if __STDC__ - 0 == 0
-static printinfo(paper, options)
-    struct paper* paper;
-    int options
-{
-#else
 static void printinfo(const struct paper* paper, int options)
 {
-#endif
     int pr = 0;
 
     if ((options & ~(OPT_CONTINUE)) == 0) {
@@ -76,38 +63,32 @@ static void printinfo(const struct paper* paper, int options)
     if (options & OPT_WIDTH) {
 	if (pr) putchar(' ');
         if (options & OPT_CM)
-          printf("%.4fcm", (float) (paperpswidth(paper)) / 72.0 * INCHxCM );
+          printf("%g cm", paperpswidth(paper) / 72.0 * INCHxCM );
 	else if (options & OPT_MM)
-          printf("%.4fmm", (float) (paperpswidth(paper)) / 72.0 * 10 * INCHxCM );
+          printf("%g mm", paperpswidth(paper) / 72.0 * 10 * INCHxCM );
 	else if (options & OPT_INCH)
-          printf("%.4f\"", (float) (paperpswidth(paper)) / 72.0 );
+          printf("%g\"", paperpswidth(paper) / 72.0 );
 	else
-          printf("%u", (unsigned) paperpswidth(paper) );
+          printf("%g", paperpswidth(paper) );
 	pr = 1;
     }
     if (options & OPT_HEIGHT) {
 	if (pr) putchar(' ');
         if (options & OPT_CM)
-          printf("%.4fcm", (float) (paperpsheight(paper)) / 72.0 * INCHxCM );
+          printf("%g cm", paperpsheight(paper) / 72.0 * INCHxCM );
 	else if (options & OPT_MM)
-          printf("%.4fmm", (float) (paperpsheight(paper)) / 72.0 * 10 * INCHxCM );
+          printf("%g mm", paperpsheight(paper) / 72.0 * 10 * INCHxCM );
 	else if (options & OPT_INCH)
-          printf("%.4f\"", (float) (paperpsheight(paper)) / 72.0 );
+          printf("%g\"", paperpsheight(paper) / 72.0 );
 	else
-          printf("%u", (unsigned) paperpsheight(paper) );
+          printf("%g", paperpsheight(paper) );
 	pr = 1;
     }
 
     putchar('\n');
 }
 
-#if __STDC__ - 0 == 0
-int main(argc, argv)
-    int argc;
-    char** argv;
-#else
 int main(int argc, char** argv)
-#endif
 {
     int c;
 
@@ -117,20 +98,12 @@ int main(int argc, char** argv)
 
     const char* progname;
 
-#if __STDC__ - 0 == 0
-    for (progname = *argv + strlen(*argv) - 1; progname != *argv
-	&& *progname != '/'; --progname);
-    if (*progname == '/') {
-	++progname;
-    }
-#else
     progname = strrchr(*argv, '/');
     if (progname) {
 	++progname;
     } else {
 	progname = *argv;
     }
-#endif
 
     while ((c = getopt(argc, argv, "adznNswhcmip:")) != EOF) {
 	switch (c) {
@@ -220,8 +193,6 @@ int main(int argc, char** argv)
 
         if (!paper) paper = systempapername();
 	if (!paper) {
-	    extern int errno;
-
 	    char errmsg[2 * MAXPATHLEN + 64];
 
 	    sprintf(errmsg, "%s: cannot get paper size from %s",
